*GHH do file: Table 9-11
clear all
capture log close
set more off
cd "$rootPath/data"


** define treatment and control group based on pre-NIRP values **
** (1) create the list of treatment (1) and control (0)***
** (2) merge treatment variable with the original data ***

use data_master.dta, clear
sort snl_key 
merge m:1 snl_key using treatment_bank.dta
drop _merge

*** (3) propensity score matching ***
*reg treatment avgpre_assets avgpre_roaa avgpre_car avgpre_net_income avgpre_zscore, r
*pre-matching probit for treatment variable *

replace avgpre_assets=avgpre_assets/100000000

******************************************************
* Table 9: Column (1)				*
******************************************************

log using "$rootPath/logfiles/Tables_9_11_diff_in_diff_exercise.log", replace

probit treatment avgpre_assets avgpre_car avgpre_roaa

* PSM using nearest-neighbor matching with replacement **
psmatch2 treatment avgpre_assets avgpre_car avgpre_roaa, neighbor(5) logit

gen matched=1 if _weight!=.
replace matched=0 if _weight==.

******************************************************
* Table 9: Column (2)			*
******************************************************

probit treatment avgpre_assets avgpre_car avgpre_roaa if matched==1

*** (4) re-run regressions ***
egen treatment1=group(_treated) if _treated!=.
replace treatment1=treatment1-1
gen post_treated=post*treatment1

******************************************************
* Table 10-11     				     *
******************************************************

foreach dv of varlist ln_nim ln_eps ln_net_inc {          
qui areg `dv' post_treated i.time post_roaa post_div_yield post_car post_loans_assets post_manuf post_services post_mining  post_transport post_retail post_finance post_realestate post_ag post_other post_localgov post_foreign post_assets post_assets2 if matched==1, absorb (ticker)
disp _newline "*****" _newline "DD dep share robustness" _newline "`dv'" _newline "*****"
est tab, keep(post_treated) b(%7.4f) se(%7.4f) p(%7.2f) stats(N r2_a)
}

foreach dv of varlist sd_return dist_default avg_kdp_5yr_pct {          
qui areg `dv'  post_treated i.time post_roaa post_div_yield post_car post_loans_assets post_manuf post_services post_mining  post_transport post_retail post_finance post_realestate post_ag post_other post_localgov post_foreign post_assets post_assets2 if matched==1, absorb (ticker)
disp _newline "*****" _newline "DD dep share robustness" _newline "`dv'" _newline "*****"
est tab, keep(post_treated) b(%7.4f) se(%7.4f) p(%7.2f) stats(N r2_a)
}

foreach dv of varlist ln_zscore ln_assets ln_car {          
qui areg `dv' post_treated i.time post_roaa post_div_yield post_car post_loans_assets post_manuf post_services post_mining  post_transport post_retail post_finance post_realestate post_ag post_other post_localgov post_foreign post_assets post_assets2 if matched==1, absorb (ticker)
disp _newline "*****" _newline "DD dep share robustness" _newline "`dv'" _newline "*****"
est tab, keep(post_treated) b(%7.4f) se(%7.4f) p(%7.2f) stats(N r2_a)
}

foreach dv of varlist yld_total_loans ln_loans_7plus {          
qui areg `dv' post_treated i.time post_roaa post_div_yield post_car post_loans_assets post_manuf post_services post_mining  post_transport post_retail post_finance post_realestate post_ag post_other post_localgov post_foreign post_assets post_assets2 if matched==1, absorb (ticker)
disp _newline "*****" _newline "DD dep share robustness" _newline "`dv'" _newline "*****"
est tab, keep(post_treated) b(%7.4f) se(%7.4f) p(%7.2f) stats(N r2_a)
}


*******************************
*******************************
*******************************
***    NO CONTROLS
*******************************
*******************************
*******************************



foreach dv of varlist ln_nim ln_eps ln_net_inc {          
qui areg `dv'  post_treated i.time  if matched==1, absorb (ticker)
disp _newline "*****" _newline "DD dep share robustness" _newline "`dv'" _newline "*****"
est tab, keep(post_treated) b(%7.4f) se(%7.4f) p(%7.2f) stats(N r2_a)
}

foreach dv of varlist sd_return dist_default avg_kdp_5yr_pct {          
qui areg `dv'  post_treated i.time  if matched==1, absorb (ticker)
disp _newline "*****" _newline "DD dep share robustness" _newline "`dv'" _newline "*****"
est tab, keep(post_treated) b(%7.4f) se(%7.4f) p(%7.2f) stats(N r2_a)
}

foreach dv of varlist ln_zscore ln_assets ln_car {          
qui areg `dv'  post_treated i.time  if matched==1, absorb (ticker)
disp _newline "*****" _newline "DD dep share robustness" _newline "`dv'" _newline "*****"
est tab, keep(post_treated) b(%7.4f) se(%7.4f) p(%7.2f) stats(N r2_a)
}

foreach dv of varlist yld_total_loans ln_loans_7plus {          
qui areg `dv'  post_treated i.time  if matched==1, absorb (ticker)
disp _newline "*****" _newline "DD dep share robustness" _newline "`dv'" _newline "*****"
est tab, keep(post_treated) b(%7.4f) se(%7.4f) p(%7.2f) stats(N r2_a)
}


log close
